@@ -494,13 +494,15 @@ armitage_eval <- function(chem.cas=NULL,
   # components:
   if (restrict.ion.partitioning)
   {
-    if (!all(c("pKa_Donor","pKa_Accept") %in% names(tcdata)))
-    {
-    # If not, pull them:
-      tcdata[, c("pKa_Donor","pKa_Accept") := 
-               as.data.frame(get_physchem_param(param = c("pKa_Donor","pKa_Accept"), 
-                                  chem.cas = casrn),row.names = casrn)]
-    }
+     if (!all(c("pKa_Donor","pKa_Accept") %in% names(tcdata)))
+     {
+     # If not, pull them:
+       tcdata[, "pKa_Donor" := as.data.frame(get_physchem_param(
+                param = "pKa_Donor", chem.cas = casrn), row.names = casrn)]
+       tcdata[, "pKa_Accept" := as.data.frame(get_physchem_param(
+                param = "pKa_Accept", chem.cas = casrn),row.names = casrn)]
+     }
+     
     # Calculate the fraction neutral:
     tcdata[, Fneutral := apply(.SD,1,function(x) calc_ionization(
         pH = this.pH,    
@@ -591,8 +593,8 @@ armitage_eval <- function(chem.cas=NULL,
   tcdata[!(is.na(gkbsa)),gkbsa:=gkbsa-duow*Tcor] %>%
     .[!(is.na(gkbsa)),kbsa:=10^gkbsa]
 
-  tcdata[option.kbsa2==TRUE & is.na(gkbsa) & gkaw<4.5, kbsa:=10^(1.08*gkow-0.7)] %>%
-    .[option.kbsa2==TRUE & is.na(gkbsa) & gkaw>=4.5, kbsa:=10^(0.37*gkow+2.56)]
+  tcdata[option.kbsa2==TRUE & is.na(gkbsa) & gkow<4.5, kbsa:=10^(1.08*gkow-0.7)] %>%
+    .[option.kbsa2==TRUE & is.na(gkbsa) & gkow>=4.5, kbsa:=10^(0.37*gkow+2.56)]
 
   tcdata[option.kbsa2==FALSE & is.na(gkbsa),kbsa:=10^(0.71*gkow+0.42)]
 
@@ -604,7 +606,7 @@ armitage_eval <- function(chem.cas=NULL,
     .[MP>298.15,ss.GSE:=ss.GSE*10^(-1*ksalt*csalt)] %>%
     .[,swat_L:=swat/F_ratio] %>%
     .[,kow:=Fneutral*kow/(10^(-1*ksalt*csalt))] %>%
-    .[,kaw:=kaw/(10^(-1*ksalt*csalt))] %>%
+    .[,kaw:=Fneutral*kaw/(10^(-1*ksalt*csalt))] %>%
     .[,kcw:=Fneutral*kcw/(10^(-1*ksalt*csalt))] %>%
     .[,kbsa:=Fneutral*kbsa/(10^(-1*ksalt*csalt))]
 
