@@ -24,30 +24,47 @@
 #'
 #'@param chem.name Either the chemical name, CAS number, or the parameters must 
 #' be specified.
+#'
 #'@param chem.cas Either the chemical name, CAS number, or the parameters must 
 #' be specified.
+#'
 #' @param dtxsid EPA's 'DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})   
 #' the chemical must be identified by either CAS, name, or DTXSIDs
+#'
 #'@param parameters Chemical parameters from parameterize_pbtk (for model = 
 #' 'pbtk'), parameterize_3comp (for model = '3compartment), 
 #' parameterize_1comp(for model = '1compartment') or parameterize_steadystate 
 #' (for model = '3compartmentss'), overrides chem.name and chem.cas.
+#'
 #'@param hourly.dose Hourly dose rate mg/kg BW/h.
+#'
 #'@param concentration Desired concentration type, 'blood' or default 'plasma'.
+#'
 #'@param suppress.messages Whether or not the output message is suppressed.
+#'
 #'@param recalc.blood2plasma Recalculates the ratio of the amount of chemical 
 #' in the blood to plasma using the input parameters. Use this if you have 
 #' 'altered hematocrit, Funbound.plasma, or Krbc2pu.
+#'
 #'@param tissue Desired tissue concentration (defaults to whole body 
 #'concentration.)
+#'
 #'@param restrictive.clearance If TRUE (default), then only the fraction of
 #' chemical not bound to protein is available for metabolism in the liver. If 
 #' FALSE, then all chemical in the liver is metabolized (faster metabolism due
 #' to rapid off-binding). 
+#'
 #'@param bioactive.free.invivo If FALSE (default), then the total concentration is treated
 #' as bioactive in vivo. If TRUE, the the unbound (free) plasma concentration is treated as 
 #' bioactive in vivo. Only works with tissue = NULL in current implementation.
 #' 
+#' @param dosing List of dosing metrics used in simulation, which includes
+#' the namesake entries of a model's associated dosing.params. For steady-state
+#' calculations this is likely to be either "daily.dose" for oral exposures or
+#' "Cinhaled" for inhalation.
+#'
+#' @param dose.units The units associated with the dose received.
+#' 
 #' @param Caco2.options A list of options to use when working with Caco2 apical to
 #' basolateral data \code{Caco2.Pab}, default is Caco2.options = list(Caco2.Pab.default = 1.6,
 #' Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.Pab.default sets the default value for 
@@ -55,7 +72,7 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #' 
 #'@param ... Additional parameters passed to parameterize function if 
 #'parameters is NULL.
@@ -72,13 +89,13 @@
 #' \insertAllCited{}
 #'
 #' @keywords 3compss
-#'
-#' @export calc_analytic_css_3compss
 calc_analytic_css_3compss <- function(chem.name=NULL,
                                    chem.cas = NULL,
                                    dtxsid = NULL,
                                    parameters=NULL,
-                                   hourly.dose=1/24,
+                                   dosing=list(daily.dose=1),
+                                   hourly.dose = NULL,
+                                   dose.units = "mg",
                                    concentration='plasma',
                                    suppress.messages=FALSE,
                                    recalc.blood2plasma=FALSE,
@@ -88,9 +105,17 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
                                    Caco2.options = list(),
                                    ...)
 {
-
-  param.names.3compss <- model.list[["3compartmentss"]]$param.names
+  if (!is.null(hourly.dose))
+  {
+     warning("calc_analytic_css_3compss deprecated argument hourly.dose replaced with new argument dose, value given assigned to dose")
+     dosing <- list(daily.dose = 24*hourly.dose)
+  }
+  
+# Load from modelinfo file:
+  THIS.MODEL <- "3compartmentss"
+  param.names <- model.list[[THIS.MODEL]]$param.names
   param.names.schmitt <- model.list[["schmitt"]]$param.names
+  parameterize_function <- model.list[[THIS.MODEL]]$parameterize.func
     
 # We need to describe the chemical to be simulated one way or another:
   if (is.null(chem.cas) & 
@@ -130,20 +155,21 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
       warning("Argument recalc.blood2plasma=TRUE ignored because parameters is NULL.")
     }
     
-    parameters <- parameterize_steadystate(
-                                    chem.cas=chem.cas,
-                                    chem.name=chem.name,
-                                    dtxsid=dtxsid,
-                                    suppress.messages=suppress.messages,
-                                    restrictive.clearance=restrictive.clearance,
-                                    Caco2.options = Caco2.options,
-                                    ...)
+    parameters <- do.call(what=parameterize_function, 
+                          args=purrr::compact(c(
+                            list(chem.cas=chem.cas,
+                                 chem.name=chem.name,
+                                 suppress.messages=suppress.messages,
+                                 Caco2.options = Caco2.options,
+                                 restrictive.clearance = restrictive.clearance
+                                 ),
+                            ...)))
 
   } else {
-    if (!all(param.names.3compss %in% names(parameters)))
+    if (!all(param.names %in% names(parameters)))
     {
       stop(paste("Missing parameters:",
-                 paste(param.names.3compss[which(!param.names.3compss %in% names(parameters))],
+                 paste(param.names[which(!param.names %in% names(parameters))],
                    collapse=', '),
                  ".  Use parameters from parameterize_steadystate."))
     }
@@ -160,25 +186,49 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
                                                    hematocrit=parameters$hematocrit)
   }
 
+  BW <- parameters$BW
+  
+  # Dose rate:
+  hourly.dose <- dosing[["daily.dose"]] /
+                   24 /
+                   BW *
+                   convert_units(MW = parameters[["MW"]],
+                                 dose.units,
+                                 "mg") # mg/kg/h
+
   Fup <- parameters$Funbound.plasma
   Rb2p <- parameters$Rblood2plasma 
-  BW <- parameters$BW
+
   # Total blood flow (gut plus arterial) into liver:
-  Qtotalliver <- parameters$Qtotal.liverc/BW^0.25 #L/h/kg BW
+  Qtotalliver <- parameters$Qtotal.liverc/BW^0.25 # L / h / kg BW
 
-# Scale up from in vitro Clint to a whole liver clearance:
-  cl <- calc_hep_clearance(parameters=parameters,
-          hepatic.model='unscaled',
-          suppress.messages=TRUE)#L/h/kg body weight
-  if (!restrictive.clearance) cl <- cl*Fup
+  # Scale glomerular filtration rate (for kidney elimination) to per kg BW:
+  Qgfr <- parameters$Qgfrc/BW^0.25 # L / h / kg BW
 
-# Calculate steady-state plasma Css, Pearce et al. (2017) equation section 2.2:
-   Css <- parameters$Fabsgut * 
-    parameters$hepatic.bioavailability *
-    hourly.dose / (
-    parameters$Qgfrc/BW^0.25 * Fup + 
-    Qtotalliver*Fup*cl /
-    (Qtotalliver + Fup*cl/Rb2p))
+  # Scale up from in vitro Clint to a whole liver clearance:
+  Clhep <- calc_hep_clearance(parameters=parameters,
+          hepatic.model="well-stirred",
+          restrictive.clearance = restrictive.clearance,
+          suppress.messages=TRUE) # L / h / kg BW
+
+  # Oral bioavailability:
+  Fabsgut <- parameters$Fabsgut
+  Fhep <- parameters$hepatic.bioavailability
+
+
+# Calculate steady-state plasma Css. With the well-stirred calculation (above)
+# this is the same equation as Wetmore et al. (2012) page 160 or 
+# Pearce et al. (2017) equation section 2.2:
+
+   Css <- hourly.dose * # Oral dose rate mg/kg/h
+          Fabsgut * # Fraction of dose absorbed from gut (in vivo or Caco-2)
+          Fhep / # Fraction of dose that escapes first-pass hepatic metabolism
+          (
+            Qgfr * Fup + # Glomerular filtration to proximal tubules (kidney)
+            Clhep # Well-stirred hepatic metabolism (liver)
+          )
+
+# Css has units of mg / L
     
 # Check to see if a specific tissue was asked for:
   if (!is.null(tissue))
@@ -237,7 +287,6 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
   return(Css)
 }
 
-
 # Add some parameters to the output from parameterize_steady_state so that
 # predict_partitioning_schmitt can run without reparameterizing
 add_schmitt.param_to_3compss <- function(parameters = NULL, chem.cas = NULL,
