@@ -4,7 +4,7 @@
 #' there are sufficient data for the specified model and species. 
 #' By default the function returns only CAS (that is, info="CAS"). 
 #' The type of information available includes chemical identifiers 
-#' ("Compound", "CASRN", "DTXSID"), in vitro
+#' ("Compound", "CAS", "DTXSID"), in vitro
 #' measurements ("Clint", "Clint.pvalue", "Funbound plasma", "Rblood2plasma"), 
 #' and physico-chemical information ("Formula", "logMA", "logP", "MW",
 #' "pKa_Accept", "pKa_Donor"). The argument "info" can be a single type of 
@@ -77,8 +77,12 @@
 #' vitro clearance assay result has a p-values greater than the threshold are
 #' set to zero.
 #' 
+#' @param physchem.exclude Exclude chemicals on the basis of physico-chemical
+#' properties (currently only Henry's law constant) as specified by 
+#' the relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param class.exclude Exclude chemical classes identified as outside of 
-#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' domain of applicability by the relevant modelinfo_[MODEL] file (default TRUE).
 #' 
 #' @param suppress.messages Whether or not the output messages are suppressed 
 #' (default FALSE).
@@ -190,6 +194,7 @@ get_cheminfo <- function(info="CAS",
                          median.only=FALSE,
                          fup.ci.cutoff=TRUE,
                          clint.pvalue.threshold=0.05,
+                         physchem.exclude=TRUE,
                          class.exclude=TRUE,
                          suppress.messages=FALSE)
 {
@@ -218,19 +223,13 @@ get_cheminfo <- function(info="CAS",
   
   #Create a local copy so we can edit it:
   chem.physical_and_invitro.data <- chem.physical_and_invitro.data
-  
-  #R CMD CHECK throws notes about "no visible binding for global variable", for
-  #each time a data.table column name is used without quotes. To appease R CMD
-  #CHECK, a variable has to be created for each of these column names and set to
-  #NULL. Note that within the data.table, these variables will not be NULL! Yes,
-  #this is pointless and annoying.
-  physiology.data <- NULL
+  physiology.data <- physiology.data
   
   #End R CMD CHECK appeasement.
 
 # Figure out which species we support
   valid.species <- 
-    colnames(httk::physiology.data)[!(colnames(httk::physiology.data)
+    colnames(physiology.data)[!(colnames(physiology.data)
     %in% c("Parameter","Units"))]
 # Standardize the species capitalization
   if (tolower(species) %in% tolower(valid.species)) species <-
@@ -319,8 +318,14 @@ get_cheminfo <- function(info="CAS",
       # Set observed clint values to 0 if clint.pvalue > threshold
       if (!is.null(clint.pvalue.threshold))
       {
-        clint.values  <- strsplit(chem.physical_and_invitro.data[,species.clint],
-          split = ",")
+        if (any(!is.na(chem.physical_and_invitro.data[, 
+            species.clint])))
+        {
+          clint.values  <- strsplit(chem.physical_and_invitro.data[,species.clint],
+            split = ",")
+        } else {
+          clint.values <- rep(NA,dim(chem.physical_and_invitro.data)[1])
+        }
         clint.pvalues <- chem.physical_and_invitro.data[,species.clint.pvalue]
         # Replace the clint.value with 0 when clint.pvalue > threshold
         clint.values[lapply(clint.values,length)!=4] <- 
@@ -558,7 +563,8 @@ For model ", model, " each chemical must have non-NA values for:",
     }
     
     # If we need to remove volatile compounds:
-    if(!is.null(log.henry.threshold)){
+    if(physchem.exclude & !is.null(log.henry.threshold))
+    {
       # keep compounds with logHenry constant less than threshold & 'NA'
       log.henry.pass <- 
         chem.physical_and_invitro.data[,"logHenry"] < 
@@ -572,6 +578,7 @@ For model ", model, " each chemical must have non-NA values for:",
         warning("Excluding volatile compounds defined as log.Henry >= ",log.henry.threshold,".")
       }
     }
+    
     # If we need to remove compounds belonging to a given chemical class:
     if (class.exclude & !is.null(chem.class.filt))
     {
