@@ -3,24 +3,27 @@
 # Pearce, Robert G., et al. "Httk: R package for high-throughput 
 # toxicokinetics." Journal of statistical software 79.4 (2017): 1.
 
+# Model identifier for the model.list:
+THIS.MODEL <- "1compartment" 
+
 # Analytic expression for steady-state plasma concentration.
-model.list[["1compartment"]]$analytic.css.func <- "calc_analytic_css_1comp"
+model.list[[THIS.MODEL]]$analytic.css.func <- "calc_analytic_css_1comp"
 
 # When calculating steady-state, which compartment do we test? 
 # ("C" is preprended):
-model.list[["1compartment"]]$steady.state.compartment <- "compartment"
+model.list[[THIS.MODEL]]$steady.state.compartment <- "compartment"
 
 # What units does the analytic function return:
-model.list[["1compartment"]]$steady.state.units <- "mg/L"
+model.list[[THIS.MODEL]]$steady.state.units <- "mg/L"
 
 # Function used for generating model parameters:
-model.list[["1compartment"]]$parameterize.func <- "parameterize_1comp"
+model.list[[THIS.MODEL]]$parameterize.func <- "parameterize_1comp"
 
 # Function called for running the model:
-model.list[["1compartment"]]$solve.func <- "solve_1comp"
+model.list[[THIS.MODEL]]$solve.func <- "solve_1comp"
 
 # Here are the tissues from tissue.data that are considered:
-model.list[["1compartment"]]$alltissues=c(
+model.list[[THIS.MODEL]]$alltissues=c(
   "adipose",
   "bone",            
   "brain",           
@@ -41,7 +44,7 @@ model.list[['1compartment']]$tissuelist <- NULL
 # These are all the parameters returned by the R model parameterization function.
 # Some of these parameters are not directly used to solve the model, but describe
 # how other parameters were calculated:
-model.list[["1compartment"]]$param.names <- c(
+model.list[[THIS.MODEL]]$param.names <- c(
   "BW",
   "Caco2.Pab",
   "Caco2.Pab.dist",
@@ -69,7 +72,7 @@ model.list[["1compartment"]]$param.names <- c(
 
 # This subset of R parameters are needed to initially parametrize the compiled
 # code for the solver: (must match ORDER under "parameters" in C code)
-model.list[["1compartment"]]$Rtosolvermap <- list(
+model.list[[THIS.MODEL]]$Rtosolvermap <- list(
   vdist="Vdist",
   ke="kelim",
   kgutabs="kgutabs",
@@ -78,32 +81,32 @@ model.list[["1compartment"]]$Rtosolvermap <- list(
 # If the model does not include an explicit gut-liver link before systemic
 # circulation, then we want to decrease the absorbed dose by the first past
 # hepatic extraction factor:
-model.list[["1compartment"]]$do.first.pass <- TRUE
+model.list[[THIS.MODEL]]$do.first.pass <- TRUE
 
 # This function translates the R model parameters into the compiled model
 # parameters:
-model.list[["1compartment"]]$compiled.parameters.init <- "getParms1comp"
+model.list[[THIS.MODEL]]$compiled.parameters.init <- "getParms1comp"
 
 # This is the ORDERED full list of parameters used by the compiled code to 
 # calculate the derivative of the system of equations describing the model 
-model.list[["1compartment"]]$compiled.param.names <- c(
+model.list[[THIS.MODEL]]$compiled.param.names <- c(
   "vdist",
   "ke",
   "kgutabs",
   "BW")
 
 # This function initializes the state vector for the compiled model:
-model.list[["1compartment"]]$compiled.init.func <- "initmod1comp"
+model.list[[THIS.MODEL]]$compiled.init.func <- "initmod1comp"
 
 # This is the function that calculates the derviative of the model as a function
 # of time, state, and parameters:
-model.list[["1compartment"]]$derivative.func <- "derivs1comp"
+model.list[[THIS.MODEL]]$derivative.func <- "derivs1comp"
 
 # This is the ORDERED list of variables returned by the derivative function:
-model.list[["1compartment"]]$derivative.output.names <- c(
+model.list[[THIS.MODEL]]$derivative.output.names <- c(
   "Ccompartment")
 
-model.list[["1compartment"]]$default.monitor.vars <- c(
+model.list[[THIS.MODEL]]$default.monitor.vars <- c(
   "Agutlumen",
   "Ccompartment",
   "Ametabolized",
@@ -111,12 +114,12 @@ model.list[["1compartment"]]$default.monitor.vars <- c(
 
 
 # Allowable units assigned to dosing input:
-model.list[["1compartment"]]$allowed.units.input <- list(
+model.list[[THIS.MODEL]]$allowed.units.input <- list(
       "oral" = c('umol','mg','mg/kg'),
        "iv" = c('umol','mg','mg/kg'))
 
 # Allowable units assigned to entries in the output columns of the ode system
-model.list[["1compartment"]]$allowed.units.output <- list(
+model.list[[THIS.MODEL]]$allowed.units.output <- list(
        "oral" = c('umol','uM','mg/L','uM*days','mg/L*days'),
        "iv" = c('umol','uM','mg/L','uM*days','mg/L*days'))
 
@@ -124,7 +127,7 @@ model.list[["1compartment"]]$allowed.units.output <- list(
 # variables of the model system including state variables and any transformed
 # outputs (for example, concentrations calculated from amounts.)
 # AUC values should also be included.
-model.list[["1compartment"]]$compartment.units <- c(
+model.list[[THIS.MODEL]]$compartment.units <- c(
     "Agutlumen"="umol",
     "Acompartment"="umol",
     "Ametabolized"="umol", 
@@ -133,16 +136,16 @@ model.list[["1compartment"]]$compartment.units <- c(
 
 # Compartment state of matter, needed for proper unit conversion, if all
 # comaprtments of the same only include one state and set it to "all":
-model.list[["1compartment"]]$compartment.state <- list(liquid="all")
+model.list[[THIS.MODEL]]$compartment.state <- list(liquid="all")
 
 # These parameters specific the exposure scenario simulated by the model:
-model.list[["1compartment"]]$dosing.params <- c(
+model.list[[THIS.MODEL]]$dosing.params <- c(
   "daily.dose",
   "initial.dose",
   "doses.per.day",
   "dosing.matrix")
 
-model.list[["1compartment"]]$routes <- list(
+model.list[[THIS.MODEL]]$routes <- list(
   "oral" = list(
     # We need to know which compartment gets the dose 
     "entry.compartment" = "Agutlumen",
@@ -165,14 +168,14 @@ model.list[["1compartment"]]$routes <- list(
 # States in C code, each of which is associated with a differential equation),
 # mostly calculated in amounts, though AUC (area under plasma concentration
 # curve) also appears here: 
-model.list[["1compartment"]]$state.vars <- c(
+model.list[[THIS.MODEL]]$state.vars <- c(
     "Agutlumen",
     "Acompartment",
     "Ametabolized", 
     "AUC")
 
 #Parameters needed to make a prediction (this is used by get_cheminfo):
-model.list[["1compartment"]]$required.params <- c(
+model.list[[THIS.MODEL]]$required.params <- c(
   "Clint", 
   "Funbound.plasma",
   "Pow",
@@ -182,15 +185,15 @@ model.list[["1compartment"]]$required.params <- c(
    )
    
 # Function for calculating Clmetabolismc after Clint is varied:
-model.list[["1compartment"]]$propagateuv.func <- "propagate_invitrouv_1comp"
+model.list[[THIS.MODEL]]$propagateuv.func <- "propagate_invitrouv_1comp"
 
 # If httk-pop is enabled:
 # Function for converting httk-pop physiology to model parameters:
-model.list[["1compartment"]]$convert.httkpop.func <- NULL
+model.list[[THIS.MODEL]]$convert.httkpop.func <- NULL
 # We want all the standard physiological calculations performed:
-model.list[["1compartment"]]$calc.standard.httkpop2httk <- TRUE
+model.list[[THIS.MODEL]]$calc.standard.httkpop2httk <- TRUE
 # These are the model parameters that are impacted by httk-pop:
-model.list[["1compartment"]]$httkpop.params <- c(
+model.list[[THIS.MODEL]]$httkpop.params <- c(
   "BW",
   "Fabsgut",
   "hepatic.bioavailability",
@@ -201,18 +204,18 @@ model.list[["1compartment"]]$httkpop.params <- c(
   "Vdist")
 
 # Do we need to recalculate partition coefficients when doing Monte Carlo?
-model.list[["1compartment"]]$calcpc <- TRUE
+model.list[[THIS.MODEL]]$calcpc <- TRUE
 
 
 # Do we need to recalculate first pass metabolism when doing Monte Carlo?
-model.list[["1compartment"]]$firstpass <- TRUE
+model.list[[THIS.MODEL]]$firstpass <- TRUE
 
 # Do we ignore the Fups where the value was below the limit of detection?
-model.list[["1compartment"]]$exclude.fup.zero <- TRUE
+model.list[[THIS.MODEL]]$exclude.fup.zero <- TRUE
 
 # These are the parameter names needed to describe steady-state dosing:
-model.list[["1compartment"]]$css.dosing.params <- list(
+model.list[[THIS.MODEL]]$css.dosing.params <- list(
   oral=c("hourly.dose"))
 
 # Filter out compounds belonging to select chemical classes
-model.list[["1compartment"]]$chem.class.filt <- c("PFAS")
+model.list[[THIS.MODEL]]$chem.class.filt <- c("PFAS")
