@@ -42,13 +42,15 @@
 #' @param dtxsid EPA's 'DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})   
 #' -- the chemical must be identified by either CAS, name, or DTXSIDs
 #' 
-#' 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
 #' 
 #' @param default.to.human Substitutes missing animal values with human values
 #' if true (hepatic intrinsic clearance or fraction of unbound plasma).
 #' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param tissuelist Specifies compartment names and tissues groupings.
 #' Remaining tissues in tissue.data are lumped in the rest of the body.
 #' However, \code{\link{solve_pbtk}} only works with the default parameters.
@@ -84,7 +86,7 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param minimum.Funbound.plasma \eqn{f_{up}} is not allowed to drop below
 #' this value (default is 0.0001).                                
@@ -93,7 +95,7 @@
 #'
 #' @param liver.density Liver density (defaults to 1.05 g/mL from International Commission on Radiological Protection (1975))
 #'
-#' @param kgutabs Oral absorption rate from gut (defaults to 2.18 1/h from Wambaugh et al. (2018))
+#' @param kgutabs Oral absorption rate from gut (determined from Peff)
 #' 
 #' @return \item{BW}{Body Weight, kg.} 
 #' \item{Clmetabolismc}{Hepatic Clearance, L/h/kg BW.} 
@@ -194,9 +196,10 @@ parameterize_pbtk <- function(
                        suppress.messages=FALSE,
                        restrictive.clearance=TRUE,
                        minimum.Funbound.plasma=0.0001,
+                       class.exclude=TRUE,
                        million.cells.per.gliver= 110, # 10^6 cells/g-liver Carlile et al. (1997)
                        liver.density= 1.05, # g/mL International Commission on Radiological Protection (1975)
-                       kgutabs = 2.18, # 1/h, Wambaugh et al. (2018)
+                       kgutabs = NA, # 1/h, Wambaugh et al. (2018)
                        Caco2.options = NULL
                        )
 {
@@ -216,6 +219,15 @@ parameterize_pbtk <- function(
   chem.cas <- out$chem.cas
   chem.name <- out$chem.name
   dtxsid <- out$dtxsid
+
+# Make sure we have all the parameters we need:
+  check_model(chem.cas=chem.cas, 
+            chem.name=chem.name,
+            dtxsid=dtxsid,
+            model="pbtk",
+            species=species,
+            class.exclude=class.exclude,
+            default.to.human=default.to.human)
   
 # Get the intrinsic hepatic clearance:  
   Clint.list <- get_clint(
@@ -264,6 +276,7 @@ parameterize_pbtk <- function(
                       chem.cas=chem.cas,
                       species=species,
                       default.to.human=default.to.human,
+                      class.exclude=class.exclude,
                       force.human.fup=force.human.clint.fup,
                       suppress.messages=suppress.messages,
                       adjusted.Funbound.plasma=adjusted.Funbound.plasma,
@@ -335,8 +348,8 @@ parameterize_pbtk <- function(
   # Create the list of parameters:
   BW <- this.phys.data["Average BW"]
   hematocrit = this.phys.data["Hematocrit"]
+  
   outlist <- c(outlist,list(BW = as.numeric(BW),
-                            kgutabs = kgutabs, # 1/h
                             Funbound.plasma = fup, # unitless fraction
                             Funbound.plasma.dist = schmitt.params$Funbound.plasma.dist,
                             hematocrit = as.numeric(hematocrit), # unitless ratio
@@ -357,6 +370,7 @@ parameterize_pbtk <- function(
   outlist <- c(outlist,
     Rblood2plasma=available_rblood2plasma(chem.cas=chem.cas,
       species=species,
+      class.exclude=class.exclude,
       adjusted.Funbound.plasma=adjusted.Funbound.plasma,
       suppress.messages=suppress.messages))
 
@@ -386,7 +400,7 @@ parameterize_pbtk <- function(
    
 # Oral bioavailability parameters:
   outlist <- c(
-    outlist, do.call(get_fabsgut, args=purrr::compact(c(
+    outlist, do.call(get_fbio, args=purrr::compact(c(
     list(
       parameters=outlist,
       dtxsid=dtxsid,
@@ -398,11 +412,11 @@ parameterize_pbtk <- function(
     Caco2.options))
     ))
 
+  # If provided by argument:
+  if (!is.na(kgutabs)) outlist[["kgutabs"]] <- kgutabs
+
   # Only include parameters specified in modelinfo:
   outlist <- outlist[model.list[["pbtk"]]$param.names]
-
-  # alphabetize:
-  outlist <- outlist[order(tolower(names(outlist)))]
   
 # Set precision:
   return(lapply(outlist, set_httk_precision))
