@@ -29,6 +29,9 @@
 #' @param default.to.human Substitutes missing fraction of unbound plasma with
 #' human values if true.
 #' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param force.human.fup Returns human fraction of unbound plasma in
 #' calculation for rats if true.
 #' When species is specified as rabbit, dog, or mouse, the human unbound
@@ -79,7 +82,19 @@
 #'
 #' @examples
 #' 
-#' parameterize_schmitt(chem.name='bisphenola')
+#' library(httk)
+#' 
+#' # Create a list of parameters (that you can potentially change):
+#' p <- parameterize_schmitt(chem.name="bisphenola")
+#' 
+#' # Predict the partition coefficients using a list of parameters:
+#' PCs <- predict_partitioning_schmitt(parameters = p)
+#' 
+#' # Lump the tissues into the compartments for model "pbtk":
+#' lump_tissues(PCs)
+#' 
+#' # Lump the tissues into a single volume of distribution
+#' calc_vdist(parameters=p)
 #' 
 #' @export parameterize_schmitt
 parameterize_schmitt <- function(chem.cas=NULL,
@@ -91,6 +106,7 @@ parameterize_schmitt <- function(chem.cas=NULL,
                           force.human.fup=FALSE,
                           adjusted.Funbound.plasma=TRUE,
                           suppress.messages=FALSE,
+                          class.exclude=TRUE,
                           minimum.Funbound.plasma=0.0001)
 {
 #R CMD CHECK throws notes about "no visible binding for global variable", for
@@ -111,8 +127,9 @@ parameterize_schmitt <- function(chem.cas=NULL,
 
 # Look up the chemical name/CAS, depending on what was provided:
   if (is.null(parameters))
-    if (any(is.null(chem.cas),is.null(chem.name),is.null(dtxsid)))
   {
+    if (any(is.null(chem.cas),is.null(chem.name),is.null(dtxsid)))
+    {
     out <- get_chem_id(
             chem.cas=chem.cas,
             chem.name=chem.name,
@@ -120,6 +137,19 @@ parameterize_schmitt <- function(chem.cas=NULL,
     chem.cas <- out$chem.cas
     chem.name <- out$chem.name                                
     dtxsid <- out$dtxsid
+    }
+    # Make sure we have all the parameters we need:
+    check_model(chem.cas=chem.cas, 
+                chem.name=chem.name,
+                dtxsid=dtxsid,
+                model="schmitt",
+                species=species,
+                class.exclude=class.exclude,
+                default.to.human=default.to.human
+                )
+  } else {
+    # Work with local copy of parameters in function(scoping):
+    if (is.data.table(parameters)) parameters <- copy(parameters) 
   }
 
 # Check the species argument for capitalization problems and whether or not it 
@@ -220,7 +250,7 @@ parameterize_schmitt <- function(chem.cas=NULL,
     Pow <- 10^get_physchem_param("logP",chem.cas=chem.cas)
   }   
 
-  if (pKa_Donor == -999)
+  if (!is.na(pKa_Donor)) if (pKa_Donor == -999)
   {
     pKa_Donor <- suppressWarnings(get_physchem_param(
                                     "pKa_Donor",
@@ -229,7 +259,7 @@ parameterize_schmitt <- function(chem.cas=NULL,
                                     dtxsid=dtxsid))
   }
   
-  if (pKa_Accept == -999)
+  if (!is.na(pKa_Accept)) if (pKa_Accept == -999)
   {    
     pKa_Accept <- suppressWarnings(get_physchem_param(
                                      "pKa_Accept",
@@ -287,19 +317,18 @@ parameterize_schmitt <- function(chem.cas=NULL,
  
   if (fup.point > 0)
   {     
-    # Get the Pearce et al. (2017) lipid binding correction:       
-    fup.adjustment <- calc_fup_correction(fup.point,
-                                          parameters=parameters,
-                                          dtxsid=dtxsid,
-                                          chem.name=chem.name,
-                                          chem.cas=chem.cas,
-                                          default.to.human=default.to.human,
-                                          force.human.fup=force.human.fup,
-                                          suppress.messages=suppress.messages)
-  
     # Apply the correction if requested:
     if (adjusted.Funbound.plasma)
     { 
+      # Get the Pearce et al. (2017) lipid binding correction:       
+      fup.adjustment <- calc_fup_correction(fup.point,
+                                            parameters=parameters,
+                                            dtxsid=dtxsid,
+                                            chem.name=chem.name,
+                                            chem.cas=chem.cas,
+                                            default.to.human=default.to.human,
+                                            force.human.fup=force.human.fup,
+                                            suppress.messages=suppress.messages)
       fup.corrected <- apply_fup_adjustment(
                          fup.point,
                          fup.correction=fup.adjustment,
@@ -307,6 +336,7 @@ parameterize_schmitt <- function(chem.cas=NULL,
                          minimum.Funbound.plasma=minimum.Funbound.plasma
                          )
     } else {
+      fup.adjustment <- 1 
       fup.corrected <- fup.point
     } 
   } else {
