@@ -48,6 +48,9 @@
 #' @param default.to.human Substitutes missing species-specific values with human values if
 #' TRUE (default is FALSE).
 #' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param force.human.clint.fup Uses human hepatic intrinsic clearance and fraction
 #' of unbound plasma in calculation of partition coefficients for rats if true.
 #' 
@@ -77,7 +80,7 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param ... Other parameters
 #' 
@@ -129,6 +132,7 @@ parameterize_steadystate <- function(
                               species="Human",
                               clint.pvalue.threshold=0.05,
                               default.to.human=FALSE,
+                              class.exclude=TRUE,
                               force.human.clint.fup=FALSE,
                               adjusted.Funbound.plasma=TRUE,
                               adjusted.Clint=TRUE,
@@ -164,6 +168,15 @@ parameterize_steadystate <- function(
   chem.name <- out$chem.name                                
   dtxsid <- out$dtxsid
 
+# Make sure we have all the parameters we need:
+  check_model(chem.cas=chem.cas, 
+              chem.name=chem.name,
+              dtxsid=dtxsid,
+              model="3compartmentss",
+              species=species,
+              class.exclude=class.exclude,
+              default.to.human=default.to.human)
+
   #Capitalize the first letter of species only:
   species <- tolower(species)
   substring(species,1,1) <- toupper(substring(species,1,1))
@@ -309,6 +322,7 @@ parameterize_steadystate <- function(
             chem.cas=chem.cas,
             dtxsid=dtxsid,
             species=species,
+            class.exclude=class.exclude,
             adjusted.Funbound.plasma=fup.corrected,
             suppress.messages=TRUE)
   Params[["Rblood2plasma"]] <- Rb2p
@@ -318,8 +332,9 @@ parameterize_steadystate <- function(
 # clearance to calculate bioavailability:
   Params[["hepatic.bioavailability"]] <- NA
   cl <- calc_hep_clearance(parameters=Params,
-          hepatic.model='unscaled',
-          suppress.messages=TRUE)#L/h/kg body weight
+          hepatic.model="unscaled",
+          restrictive.clearance = restrictive.clearance,
+          suppress.messages=TRUE) #L/h/kg body weight
           
 # "hepatic bioavailability" simulates first-pass hepatic metabolism since we 
 # don't explicitly model blood from the gut:
@@ -334,7 +349,7 @@ parameterize_steadystate <- function(
   if (is.na(Params[['hepatic.bioavailability']])) browser() 
 
   Params <- c(
-    Params, do.call(get_fabsgut, args=purrr::compact(c(
+    Params, do.call(get_fbio, args=purrr::compact(c(
     list(
       parameters=Params,
       dtxsid=dtxsid,
