@@ -90,6 +90,8 @@ scale_dosing <- function(
     as.numeric(dosing$daily.dose) * scale.factor
   if (!is.null(dosing$forcings)) dosing$forcings[,"forcing_values"] <- 
     as.numeric(dosing$forcings[,"forcing_values"]) * scale.factor
+  if (!is.null(dosing$Cinhaled)) dosing$Cinhalde <-
+    as.numeric(dosing$Cinhaled) * scale.factor
     
   return(dosing)
 }
\ No newline at end of file
