@@ -1,8 +1,29 @@
 #' Solve_3comp
 #' 
 #' This function solves for the amounts or concentrations of a chemical in
-#' different tissues as functions of time based on the dose and dosing
-#' frequency.  It uses a three compartment model with partition coefficients.
+#' the blood of three different compartments representing the body.
+#' The volumes of the three compartments are chemical specific, determined from
+#' the true tissue volumes multipled by the partition coefficients:
+#' \deqn{V_{pv} = V_{gut}}
+#' \deqn{V_{liv} = \frac{K_{liv}*f_{up}}{R_{b:p}}V_{liver}}
+#' \deqn{V_{sc} = \frac{K_{sc}*f_{up}}{R_{b:p}}V_{rest}}
+#' where "pv" is the portal vein, "liv" is the liver, and "sc" is the systemic
+#' compartment; V_gut, V_liver, and V_rest are physiological tissue volumes;
+#' K_x are chemical- and tissue-specific equlibrium partition coefficients 
+#' between tissue and free chemcial concentration in plasma;
+#' f_up is the chemical-specific fraction unbound in plasma; and R_b:p is the 
+#' chemical specific ratio of concentrations in blood:plasma.
+#' The blood concentrations evolve according to:
+#' \deqn{\frac{d C_{pv}}{dt} = \frac{1}{V_{pv}}\left(k_{abs}A_{si} + Q_{pv}C_{sc}-Q_{pv}C_{pv}\right)}
+#' \deqn{\frac{d C_{liv}}{dt} = \frac{1}{V_{liv}}\left(Q_{pv}C_{pv} + Q_{ha}C_{sc}-\left(Q_{pv} + Q{ha}\right)C_{liv}-\frac{1}{R_{b:p}}Cl_{h}C_{liv}\right)}
+#' \deqn{\frac{d C_{sc}}{dt} = \frac{1}{V_{sc}}\left(\left(Q_{pv} + Q_{ha}\right)C_{liv} - \left(Q_{pv} + Q_{ha}\right)C_{sc} - \frac{f_{up}}{R_{b:p}}*Q_{GFR}*C_{sc}\right)}
+#' where "ha" is the hepatic artery, Q's are flows, "GFR" is the glomerular
+#' filtration rate in the kidney, 
+# and Cl_h is the chemical-specific whole liver metabolism 
+#' clearance (scaled up from intrinsic clearance, which does not depend on flow).
+#' Plasma concentration in compartment x is given by 
+#' \eqn{C_{x,plasma} = \frac{C_{x}}{R_{b2p}}} for a tissue independent value of 
+#' \eqn{R_{b2p}}.
 #' 
 #' Note that the timescales for the model parameters have units of hours while 
 #' the model output is in days.
@@ -10,7 +31,8 @@
 #' Default of NULL for doses.per.day solves for a single dose.
 #' 
 #' The compartments used in this model are the gutlumen, gut, liver, and
-#' rest-of-body, with the plasma equivalent to the liver plasma.
+#' rest-of-body, with the plasma related to the concentration in the blood
+#' in the systemic compartment by the blood:plasma ratio.
 #' 
 #' Model Figure 
 #' \if{html}{\figure{3comp.jpg}{options: width="60\%" alt="Figure: Three
@@ -22,8 +44,6 @@
 #' appropriate physiological data(volumes and flows) but substitues human
 #' fraction unbound, partition coefficients, and intrinsic hepatic clearance.
 #' 
-#' 
-#' 
 #' @param chem.name Either the chemical name, CAS number, or the parameters
 #' must be specified.
 #' @param chem.cas Either the chemical name, CAS number, or the parameters must
@@ -52,9 +72,6 @@
 #' @param output.units A named vector of output units expected for the model
 #' results. Default, NULL, returns model results in units specified in the
 #' 'modelinfo' file. See table below for details.
-#' @param method Method used by integrator (deSolve).
-#' @param rtol Argument passed to integrator (deSolve).
-#' @param atol Argument passed to integrator (deSolve).
 #' @param default.to.human Substitutes missing animal values with human values
 #' if true (hepatic intrinsic clearance or fraction of unbound plasma).
 #' @param recalc.blood2plasma Recalculates the ratio of the amount of chemical
@@ -83,12 +100,12 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param monitor.vars Which variables are returned as a function of time. 
 #' Defaults value of NULL provides "Cliver", "Csyscomp", "Atubules", 
 #' "Ametabolized", "AUC"
-#' @param ... Additional arguments passed to the integrator.
+#' @param ... Additional arguments passed to the integrator (deSolve).
 #'
 #' @return A matrix of class deSolve with a column for time(in days) and each
 #' compartment, the plasma concentration, area under the curve, and a row for
@@ -109,6 +126,7 @@
 #'             days=1,
 #'             tsteps=2)
 #'
+#' \donttest{
 #' # By storing the model parameters in a vector first, you can potentially
 #' # edit them before using the model:
 #' params <-parameterize_3comp(chem.cas="80-05-7")
@@ -128,6 +146,7 @@
 #' solve_3comp(chem.name="Besonprodil",
 #'             daily.dose=1, dose=NULL,
 #'             days=2.5, doses.per.day=4)
+#' }
 #'
 #' @seealso \code{\link{solve_model}}
 #'
@@ -136,6 +155,8 @@
 #' @seealso \code{\link{calc_analytic_css_3comp}}
 #'
 #' @export solve_3comp
+#'
+#' @useDynLib httk
 solve_3comp <- function(chem.name = NULL,
                     chem.cas = NULL,
                     dtxsid = NULL,
@@ -154,7 +175,6 @@ solve_3comp <- function(chem.name = NULL,
                     input.units='mg/kg',
                     # output.units='uM',
                     output.units=NULL,
-                    method="lsoda",rtol=1e-8,atol=1e-12,
                     default.to.human=FALSE,
                     recalc.blood2plasma=FALSE,
                     recalc.clearance=FALSE,
@@ -191,7 +211,6 @@ solve_3comp <- function(chem.name = NULL,
     species=species,
     input.units=input.units,
     output.units=output.units,
-    method=method,rtol=rtol,atol=atol,
     recalc.blood2plasma=recalc.blood2plasma,
     recalc.clearance=recalc.clearance,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
@@ -204,8 +223,5 @@ solve_3comp <- function(chem.name = NULL,
                       Caco2.options=Caco2.options),
     ...)
   
-  out <- cbind(out,out[,"Csyscomp"])
-  colnames(out)[length(colnames(out))]<-"Cplasma"
-    
   return(out) 
 }
