@@ -3,6 +3,25 @@
 #' This function solves for the amounts or concentrations of a chemical
 #' in different tissues as functions of time as a result of inhalation 
 #' exposure to an ideal gas.
+#' In this PBTK formulation. \eqn{C_{tissue}} is the concentration in tissue at 
+#' time t. Since the perfusion limited partition coefficients describe 
+#' instantaneous equilibrium between the tissue and the free fraction in 
+#' plasma, the whole plasma concentration is 
+#' \eqn{C_{tissue,plasma} = \frac{1}{f_{up}*K_{tissue2fup}}*C_{tissue}}. 
+#' Note that we use a single, 
+#' constant value of \eqn{f_{up}} across all tissues. Corespondingly the free 
+#' plasma 
+#' concentration is modeled as 
+#' \eqn{C_{tissue,free plasma} = \frac{1}{K_{tissue2fup}}*C_tissue}. 
+#' The amount of blood flowing from tissue x is \eqn{Q_{tissue}} (L/h) at a 
+#' concentration 
+#' \eqn{C_{x,blood} = \frac{R_{b2p}}{f_{up}*K_{tissue2fup}}*C_{tissue}}, where 
+#' we use a 
+#' single \eqn{R_{b2p}} value throughout the body.
+#' Metabolic clearance is modelled as being from the total plasma 
+#' concentration here, though it is restricted to the free fraction in 
+#' \code{\link{calc_hep_clearance}} by default. Renal clearance via 
+#' glomerulsr filtration is from the free plasma concentration.
 #' 
 #' The default dosing scheme involves a specification of the start time
 #' of exposure (exp.start.time), the concentration of gas inhaled (exp.conc),
@@ -118,20 +137,12 @@
 #' results. Default, NULL, returns model results in units specified in the
 #' 'modelinfo' file. See table below for details.
 #' 
-#' @param method Method used by integrator (deSolve).
-#' (Note: There are precision differences between M1 Mac and other OS systems
-#' for this function due to how long doubles are handled. To replicate results
-#' between various OS systems we suggest changing the default method of "lsoda"
-#' to "lsode" and also adding the argument mf = 10.
-#' See [deSolve::ode()] for further details.)
-#' 
-#' @param rtol Argument passed to integrator (deSolve).
-#' 
-#' @param atol Argument passed to integrator (deSolve).
-#' 
 #' @param default.to.human Substitutes missing animal values with human values
 #' if true (hepatic intrinsic clearance or fraction of unbound plasma).
 #' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param recalc.blood2plasma Recalculates the ratio of the amount of chemical
 #' in the blood to plasma using the input parameters, calculated with
 #' hematocrit, Funbound.plasma, and Krbc2pu.
@@ -176,7 +187,12 @@
 #' @param VD Anatomical dead space (L), to be modulated especially as part of
 #' simulating the state of exercise
 #' 
-#' @param ... Additional arguments passed to the integrator.
+#' @param ... Additional arguments passed to the integrator (deSolve).
+#' (Note: There are precision differences between M1 Mac and other OS systems
+#' for this function due to how long doubles are handled. To replicate results
+#' between various OS systems we suggest changing the default method of "lsoda"
+#' to "lsode" and also adding the argument mf = 10.
+#' See [deSolve::ode()] for further details.)
 #'
 #' @return A matrix of class deSolve with a column for time(in days), each
 #' compartment, the area under the curve, and plasma concentration and a row
@@ -254,8 +270,8 @@ solve_gas_pbtk <- function(chem.name = NULL,
                            input.units = "ppmv", # assume input units are ppmv with updated inhalation model
                            # input.units = "uM",
                            output.units=NULL,
-                           method="lsoda",rtol=1e-8,atol=1e-12,
                            default.to.human=FALSE,
+                           class.exclude=TRUE,
                            recalc.blood2plasma=FALSE,
                            recalc.clearance=FALSE,
                            adjusted.Funbound.plasma=TRUE,
@@ -401,13 +417,13 @@ solve_gas_pbtk <- function(chem.name = NULL,
     species=species,
     input.units=input.units,
     output.units=output.units,
-    method=method,rtol=rtol,atol=atol,
     recalc.blood2plasma=recalc.blood2plasma,
     recalc.clearance=recalc.clearance,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
     parameterize.arg.list = list(
       regression=regression,
       default.to.human=default.to.human,
+      class.exclude=class.exclude,
       restrictive.clearance = restrictive.clearance,
       exercise = exercise,
       vmax = vmax,
