@@ -1,4 +1,8 @@
-#R CMD BATCH --no-timing --no-restore --no-save other_tests.R other_tests.Rout
+# R CMD BATCH --no-timing --no-restore --no-save other_tests.R other_tests.Rout
+
+# Get rid of anything in the workspace:
+rm(list=ls()) 
+
 library(httk)
 
 #calc_css(chem.name='nicotine')
